==> apache-druid-25.0.0-src.tar.gz: apache-druid-25.0.0-src/web-console/src/druid-models/metric-spec/metric-spec.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { JSON_SAMPLE } from '../../utils/sampler.mock';

import { getMetricSpecs } from './metric-spec';

describe('metric-spec', () => {
  describe('getMetricSecs', () => {
    it('works for empty', () => {
      expect(getMetricSpecs({ header: ['header'], rows: [] }, {}, false)).toEqual([
        { name: 'count', type: 'count' },
      ]);
    });

    it('works with json', () => {
      expect(getMetricSpecs(JSON_SAMPLE, {}, false)).toEqual([
        {
          name: 'count',
          type: 'count',
        },
        {
          fieldName: 'followers',
          name: 'sum_followers',
          type: 'longSum',
        },
        {
          fieldName: 'spend',
          name: 'sum_spend',
          type: 'doubleSum',
        },
      ]);
    });

    it('works with csv', () => {
      expect(getMetricSpecs(JSON_SAMPLE, {}, true)).toEqual([
        {
          name: 'count',
          type: 'count',
        },
        {
          fieldName: 'followers',
          name: 'sum_followers',
          type: 'longSum',
        },
        {
          fieldName: 'spend',
          name: 'sum_spend',
          type: 'doubleSum',
        },
        {
          fieldName: 'id',
          name: 'sum_id',
          type: 'longSum',
        },
      ]);
    });
  });
});

==> apache-druid-32.0.1-src.tar.gz: apache-druid-32.0.1-src/web-console/src/druid-models/metric-spec/metric-spec.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { EMPTY_SAMPLE, JSON_SAMPLE } from '../../utils/sampler.mock';

import { getMetricSpecs } from './metric-spec';

describe('metric-spec', () => {
  describe('getMetricSecs', () => {
    it('works for empty', () => {
      expect(getMetricSpecs(EMPTY_SAMPLE, {}, false)).toEqual([{ name: 'count', type: 'count' }]);
    });

    it('works with json', () => {
      expect(getMetricSpecs(JSON_SAMPLE, {}, false)).toEqual([
        {
          name: 'count',
          type: 'count',
        },
        {
          fieldName: 'followers',
          name: 'sum_followers',
          type: 'longSum',
        },
        {
          fieldName: 'spend',
          name: 'sum_spend',
          type: 'doubleSum',
        },
      ]);
    });

    it('works with csv', () => {
      expect(getMetricSpecs(JSON_SAMPLE, {}, true)).toEqual([
        {
          name: 'count',
          type: 'count',
        },
        {
          fieldName: 'followers',
          name: 'sum_followers',
          type: 'longSum',
        },
        {
          fieldName: 'spend',
          name: 'sum_spend',
          type: 'doubleSum',
        },
        {
          fieldName: 'id',
          name: 'sum_id',
          type: 'longSum',
        },
      ]);
    });
  });
});
